@@ -1,19 +1,21 @@
 import sys
-import json
 from pathlib import Path, PosixPath
 import fire
-from typing import Optional, Union
+from typing import Optional, Union, List
 
-from .classes import LogseqPage, LogseqBlock
+from .pages import LogseqPage
+from .blocks import LogseqBlock
 
-__VERSION__ = LogseqPage.__VERSION__
+__VERSION__: str = "3.0"
+
+__ALL__ = ["parse_file", "parse_text", "LogseqPage", "LogseqBlock"]
 
 
 def parse_file(
     file_path: Union[str, PosixPath] = None,
     verbose: bool = False,
     out_format: Optional[str] = None,
-):
+) -> Union[List[dict], str, LogseqPage]:
     """
     Parameters:
     -----------
@@ -24,6 +26,11 @@ def parse_file(
 
     out_format: default to None
         Either 'json' or 'toml'. For example can be piped directly to jq
+        If None, returns the LogseqPage directly
+
+    Returns:
+    --------
+    Depending on out_format: Union[LogseqPage, List[dict], str]
     """
     if file_path is not None:
         assert Path(file_path).exists(), f"{file_path} not found"
@@ -38,10 +45,24 @@ def parse_file(
     )
 
     if out_format:
-        return parsed.export(format=out_format)
+        return parsed.format(format=out_format)
     else:
         return parsed
 
+def parse_text(
+    content: str,
+    verbose: bool = False,
+    ) -> LogseqPage:
+    """
+    Parameters:
+    -----------
+    content: string content
+    verbose: bool, default to False
+
+    Returns
+    """
+    return LogseqPage(content=content, verbose=verbose)
+
 
 def cli() -> None:
     fire.Fire(parse_file)
